"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getForcedLeadingFn;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {fn} transform function applying the leading
 */
function getForcedLeadingFn(rule) {
  const noop = input => input;

  const remove = input => {
    const fragments = input.split('\n');
    return fragments[0] === '' ? fragments.slice(1).join('\n') : input;
  };

  const lead = input => {
    const fragments = input.split('\n');
    return fragments[0] === '' ? input : ['', ...fragments].join('\n');
  };

  if (!rule) {
    return noop;
  }

  const leading = getForcedLeading(rule);

  if (leading === null) {
    return noop;
  }

  return leading ? lead : remove;
}
/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {boolean|null} transform function applying the leading
 */


function getForcedLeading(rule) {
  if (!rule) {
    return null;
  }

  const _rule = (0, _slicedToArray2.default)(rule, 2),
        _rule$ = (0, _slicedToArray2.default)(_rule[1], 2),
        severity = _rule$[0],
        applicable = _rule$[1];

  const negated = applicable === 'never';

  if (severity === 0) {
    return null;
  }

  return !negated;
}
//# sourceMappingURL=get-forced-leading-fn.js.map